@@ -1157,7 +1157,7 @@ merge.ChromatinAssay <- function(
       if (all(count_nonzero > 0)) {
         merged.counts <- RowMergeSparseMatrices(
           mat1 = all.counts[[1]],
-          mat2 = all.counts[[2:length(x = all.counts)]]
+          mat2 = all.counts[2:length(x = all.counts)]
         )
         reduced.ranges <- StringToGRanges(regions = rownames(x = merged.counts))
       } else {
@@ -1167,7 +1167,7 @@ merge.ChromatinAssay <- function(
       if (all(data_nonzero > 0)) {
         merged.data <- RowMergeSparseMatrices(
           mat1 = all.data[[1]],
-          mat2 = all.data[[2:length(x = all.data)]]
+          mat2 = all.data[2:length(x = all.data)]
         )
         reduced.ranges <- SetIfNull(
           x = reduced.ranges,
